@@ -2,6 +2,6 @@
 #![cfg_attr(not(feature = "std"), no_std)]
 #![warn(missing_docs)]
 
-#[cfg(any(cortex_m, doc))]
+#[cfg(any(cortex_m, doc, test))]
 pub mod cortex_m;
 pub use stackdump_core as core;
